import Image from "next/image";

const ProductQuestionCard = ({ question, isLatest }) => {
    
  return (
    <div className={`w-full flex flex-col gap-4 ${!isLatest && "border-b border-border-main pb-2"}`}>
      <strong>{question.questionText}</strong>
      {question.questionImage && question.questionImage !== "" && (
        <div className="w-full flex items-center justify-center p-2">
          <Image
            src={question.questionImage}
            width={"0"}
            height={"0"}
            sizes="100vw"
            className="h-36 w-auto object-contain"
            alt={question.qustionImageAlt}
            title={question.questionImageTitle}
          />
        </div>
      )}
      {question.answersType === "text" && (
        <div className="w-full flex flex-col gap-3">
          {question.answers.map((item, index) => (
            <p
              key={index}
              className={`${
                question.trueAnswerId === item.id && "text-success-main"
              }`}
            >
              {index + 1} - {item.text}
            </p>
          ))}
        </div>
      )}
      {question.answersType === "image" && (
        <div className="w-full grid grid-cols-2 md:grid-cols-4 gap-3">
          {question.answers.map((item, index) => (
            <div
              className={`w-full h-auto rounded-lg border border-border-main p-3 flex items-center justify-center ${
                question.trueAnswerId === item.id &&
                "border-success-main border-2"
              }`}
              key={index}
            >
              <Image
                src={item.image}
                alt={item.imageAlt}
                title={item.imageTitle}
                width={"0"}
                height={"0"}
                sizes="100vw"
                className="w-auto h-[120px] object-contain"
              />
            </div>
          ))}
        </div>
      )}
      {question.hint && question.hint !== "" && (
        <div className="whitespace-pre-wrap">{question.hint}</div>
      )}
    </div>
  );
};

export default ProductQuestionCard;
